
#cs

iTermPaste is a tool for inputting data into iTerm from a CSV file or spreadsheet.  The format iTermPaste requires, is a tab delimited plaintext file called "text.txt" with the following fields:

source text
target text
context (in my case this was empty)
gender (in my case this was empty)
status, being either A, D, P or U
comment (in my case this was empty)

Make sure you have six columns!  If you have only 5 (because the 6th column is empty and your text editor stripped the trailing tab character), the script won't work.

In iTerm, go to the page with the list of items you want to edit.  Click on one item's "edit" link so that you can tell the script where to click on the individual terms editing page.

The script will overwrite stuff, but it won't click "Update" -- you can do that yourself, or use the backbutton if something goes wrong.

Run the script, and then set up the mouseclick positions:
* To let the script know where the "Edit" link is, position your mouse on the "Edit" link and press Alt+e.
* To let the script know where the "Translation" box more or less is, position your mouse over it, and press Alt+p (mnemonic for "paste").
* You can set the Alt+e and Alt+p positions at any time (this is helpful because the positions sometimes move slightly)
* Press Alt+l (lowercase L) to initiate the pasting action.
* Press Ctrl+e to move the mouse back to the Edit link if you've moved your mouse elsewhere for whatever reason
* Press Ctrl+k to force the mouse to click at its current position (useful when the Edit link refuses to activate and you can't just use Enter on it)

The process is:

1. Click "Edit" using ENTER or Ctrl+k or your mouse
2. When the next page has loaded, press Ctrl+l
3. The script will move the mouse to the Translation box and it will display the term whose information is about to the pasted.  Check visually if the source term in the message is the same as the source term on the page.  If not, take evasive or corrective action.  The mouse will also move back to the correct position to click "Edit" on the next page.
4. When you're satisfied that (a) the mouse is over the Translation box and (b) the term in the message is the correct term, press ENTER.
5. The fields will be filled in, and the "Update" button will be activated (but not pressed/clicked).
6. If you're happy with what had been filled in, press ENTER or click the Update button.
7. Optional: use Ctrl+e to move the mouse to the "Edit" link.
8. Go back to step 1.

You can stop the script at any time, and delete the finished lines from the "text.txt" file.

#ce


Global $j
Global $i
Global $filereadline
Global $splitted
Global $searchpos
Global $paster

$searchpos = 1
$paster = 1

$j = 0
$i = 1

MsgBox (0, "Before going further", "Set up your main shortcuts now... Alt+e and Alt+p", 0)

#include <File.au3>

HotKeySet ("!l", "justpaste")
HotKeySet ("^k", "clicky")
HotKeySet ("!e", "remouse")
HotKeySet ("^e", "showe")
HotKeySet ("!p", "oomouse")

While 1
    Sleep(100)
WEnd


Func remouse()
$searchpos = MouseGetPos ()
EndFunc

Func showe()
MouseMove ($searchpos[0], $searchpos[1], 0)
EndFunc

Func oomouse()
$paster = MouseGetPos ()
EndFunc

Func clicky()
$clicckey = MouseGetPos ()
MouseClick ("left", $clicckey[0], $clicckey[1], 1, 0)
EndFunc

Func justpaste()

MouseMove ($paster[0], $paster[1], 5)

$fileopen = FileOpen ("text.txt", 0)
; $filecountlines = _FileCountLines ("text.txt")

$filereadline = FileReadLine ("text.txt", $i)

$splitted = StringSplit ($filereadline, @TAB, 1)

If $splitted[0] = 1 Then
MsgBox (0, "Whoops!", "There are no more terms!", 0)
Exit
EndIf

Sleep ("10")

If $splitted[5] = "A" Then 
$statussy = "A (Approved)"
ElseIf $splitted[5] = "D" Then 
$statussy = "D (Do not translate)"
ElseIf $splitted[5] = "P" Then 
$statussy = "P (Pending)"
ElseIf $splitted[5] = "U" Then 
$statussy = "U (Unapproved)"
EndIf

MsgBox (0, "This is the term about to be pasted", "Source: " & $splitted[1] & @CRLF & @CRLF & "Target: " & $splitted[2] & @CRLF & @CRLF & "Context: " & $splitted[3] & @CRLF & @CRLF & "Gender: " & $splitted[4] & @CRLF & @CRLF & "Status: " & $statussy & @CRLF & @CRLF & "Comment: " & $splitted[6] & @CRLF & @CRLF & "Check that the mouse cursor is over the paste box, and hit ENTER" , 0)

$clicckey = MouseGetPos ()
MouseClick ("left", $clicckey[0], $clicckey[1], 1, 0)

WinActivate ("Novell", "")
WinWaitActive ("Novell", "")

ClipPut ($splitted[2])
Sleep ("10")
Send ("^a")
Sleep ("10")
Send ("^v")
Sleep ("10")
Send ("{TAB}")
Sleep ("10")

ClipPut ($splitted[3])
Sleep ("10")
Send ("^a")
Sleep ("10")
Send ("^v")
Sleep ("10")
Send ("{TAB}")
Sleep ("10")

ClipPut ($splitted[4])
Sleep ("10")
Send ("^a")
Sleep ("10")
Send ("^v")
Sleep ("10")
Send ("{TAB}")
Sleep ("10")

Send ($splitted[5])
Sleep ("10")
Send ("{TAB}")
Sleep ("10")

ClipPut ($splitted[6])
Sleep ("10")
Send ("^a")
Sleep ("10")
Send ("^v")
Sleep ("10")
Send ("{TAB}")
Sleep ("10")

MouseMove ($searchpos[0], $searchpos[1], 0)

$j = $j + 1
$i = $i + 1

FileClose ($fileopen)

EndFunc

; MsgBox (0, "Done!", "Did " & $j & " segments", 10)

